#
# spec file for package python-google-api-python-client
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Test scripts not included in source archive
# https://github.com/google/google-api-python-client/issues/513
%bcond_with test

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-google-api-python-client
Version:        1.7.4
Release:        3.43
Summary:        Google APIs Python Client
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/google/google-api-python-client
Source:         https://files.pythonhosted.org/packages/source/g/google-api-python-client/google-api-python-client-%{version}.tar.gz
Patch0:         hidePythonDeps.patch
BuildRequires:  %{python_module httplib2 >= 0.9.2}
BuildRequires:  %{python_module oauth2client >= 1.5.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.6.1}
BuildRequires:  %{python_module uritemplate  >= 3.0.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
# Test requirements
BuildRequires:  %{python_module nose}
# Python 2 test requirements
BuildRequires:  python-mock
%endif
Requires:       python-httplib2 >= 0.9.2
Requires:       python-oauth2client >= 1.5.0
Requires:       python-six >= 1.6.1
Requires:       python-uritemplate  >= 3.0.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
# Package renamed in SLE 12, do not remove Provides, Obsolete directives
# until after SLE 12 EOL
Provides:       google-api-python-client = %{version}
Obsoletes:      google-api-python-client < %{version}
%python_subpackages

%description
Google APIs Client Library for Python

%prep
%setup -q -n google-api-python-client-%{version}
%patch0

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%python_expand nosetests-%{$python_bin_suffix}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGELOG
%license LICENSE
%{python_sitelib}/*

%changelog
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Mon Aug 13 2018 mcepl@suse.com
- Remove dependency on unittest2
- Upgrade to 1.7.4: just series of minor bugfixes
* Thu May 31 2018 toddrme2178@gmail.com
- Add bug report about tests
* Tue May 29 2018 tbechtold@suse.com
- update to 1.6.7:
  - Make body optional for requests with no parameters. (#446)
  - Fix retying on socket.timeout. (#495)
  - Match travis matrix with tox testenv. (#498)
  - Remove oauth2client._helpers dependency. (#493)
  - Remove unused keyring test dependency. (#496)
  - discovery.py: remove unused oauth2client import. (#492)
  - Update README to reference GCP API client libraries. (#490)
  - Warn when constructing BatchHttpRequest using the legacy batch URI (#488)
  - Increase the default media chunksize to 100MB. (#482)
  - Remove unnecessary parsing of mime headers in HttpRequest.__init__ (#467)
  - Proactively refresh credentials when applying and treat a missing
    `access_token` as invalid. Note: This change reveals surprising behavior
    between default credentials and batches. If you allow
    `googleapiclient.discovery.build` to use default credentials *and* specify
    different credentials by providing `batch.execut()` with an explicit `http`
    argument, your individual requests will use the default credentials and
  * not* the credentials specified to the batch http. To avoid this, tell
    `build` explicitly not to use default credentials by specifying
    `build(..., http=httplib2.Http()`. (#469)
  - Remove mutual exclusivity check for developerKey and credentials (#465)
  - Handle unknown media length. (#406)
  - Handle variant error format gracefully. (#459)
  - Avoid testing against Django >= 2.0.0 on Python 2. (#460)
- Use %%license
* Sat Sep 30 2017 arun@gmx.de
- update to version 1.6.4:
  * Warn when google-auth credentials are used but
    google-auth-httplib2 isn't available. (#443)
- changes from version 1.6.3:
  * Add notification of maintenance mode to README. (#410)
  * Fix generation of methods with abnormal page token
    conventions. (#338)
  * Raise ValueError is credentials and developerKey are both
    specified. (#358)
  * Re-generate documentation. (#364, #373, #401)
  * Fix method signature documentation for multiline required
    parameters. (#374)
  * Fix ZeroDivisionError in MediaDownloadProgress.progress. (#377)
  * Fix dead link to WebTest in README. (#378)
  * Fix details missing in googleapiclient.errors.HttpError. (#412)
  * Don't treat httplib2.Credentials as oauth credentials. (#425)
  * Various fixes to the Django sample. (#413)
* Mon Jul 10 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Update source URL.
- Update to Version 1.6.2
  * Fixed a bug where application default credentials would still be used even
    when a developerKey was specified. (#347)
  * Official support for Python 3.5 and 3.6. (#341)
- Update to Version 1.6.1
  * Fixed a bug where using google-auth with scoped credentials would fail. (#328)
- Update to Version 1.6.0
  * Support for Python 2.6 has been dropped. (#319)
  * The credentials argument to discovery.build and discovery.build_from_document
    can be either oauth2client credentials or google-auth credentials. (#319)
  * discovery.build and discovery.build_from_document now unambiguously use the
    http argument to make all requests, including the request for the discovery
    document. (#319)
  * The http and credentials arguments to discovery.build and
    discovery.build_from_document are now mutually exclusive, eliminating a
    buggy edge case. (#319)
  * If neither http or credentials is specified to discovery.build and
    discovery.build_from_document, then Application Default Credentials will
    be used. The library prefers google-auth for this if it is available, but
    can also use oauth2client's implementation. (#319)
  * Fixed resumable upload failure when receiving a 308 response. (#312)
  * Clarified the support versions of Python 3. (#316)
- Update to Version 1.5.5
  * Allow explicit MIME type specification with media_mime_type keyword argument.
  * Fix unprintable representation of BatchError with default constructor. (#165)
  * Refresh all discovery docs, not just the preferred ones. (#298)
  * Update minimum httplib2 dependency to >=0.9.2.
* Thu Nov  3 2016 rjschwei@suse.com
- Fix description of -test sub-package
* Fri Oct 28 2016 rjschwei@suse.com
- Add missing runtime dependencies as requires
* Fri Oct 28 2016 lchiquitto@suse.de
- Use new package's name in -test sub-package requires
* Thu Oct 27 2016 rjschwei@suse.com
- Include in SLE 12 (FATE#321630, bsc#1002895)
* Tue Oct 18 2016 rjschwei@suse.com
- Renamed package to python-google-api-python-client
  * Conform with openSUSE/SUSE naming policy
* Tue Oct 18 2016 rjschwei@suse.com
- Upgrade to version 1.5.4 (bsc#1002895)
  * Properly handle errors when the API returns a mapping or sequence. (#289)
  * Upgrade to unified uritemplate 3.0.0. (#293)
  * Allow oauth2client 4.0.0, with the caveat that file-based discovery
    caching is disabled.
- From 1.5.2
  * Allow using oauth2client >= 1.5.0, < 4.0.0. (#265)
  * Fix project_id argument description. (#257)
  * Retry chunk uploaded on rate limit exceeded errors. (#255)
  * Obtain access token if necessary in BatchHttpRequest.execute(). (#232)
  * Warn when running tests using HttpMock without having a cache. (#261)
- From 1.5.1
  * Allow using versions of oauth2client < 2.0.0. (#197)
  * Check both current and new API discovery URL. (#202)
  * Retry http requests on connection errors and timeouts. (#218)
  * Retry http requests on rate limit responses. (#201)
  * Import guards for ssl (for Google App Engine). (#220)
  * Use named loggers instead of the root logger. (#206)
  * New search console example. (#212)
- From 1.5.0
  * Fix file stream recognition in Python 3 (#141)
  * Fix non-resumable binary uploads in Python 3 (#147)
  * Default to 'octet-stream' if mimetype detection fails (#157)
  * Handle SSL errors with retries (#160)
  * Fix incompatibility with oauth2client v2.0.0 (#182)
* Thu Nov 12 2015 rjschwei@suse.com
- Upgrade to version 1.4.2 (bsc#954690)
  * oauth2client is now a separate package python-oauth2client
  * Need to update this version as the previous embedded version for
    oauth2client lacks necessary features for google-cloud-sdk
  * remove patch no_embed_uritempl_dep.patch
  * add patch hidePythonDeps.patch
  * Add automatic caching for the discovery docs.
  - From 1.4.1
  * Add the googleapiclient.discovery.Resource.new_batch_http_request method.
  - From 1.4.0
  * Python 3 support.
  - From 1.3.2
  * Fix an infinite loop for downloading small files.
  * Fix a unicode error in error encoding.
  * Better handling of `content-length` in media requests.
  * Add support for methodPath entries containing colon.
  - From 1.3.1
  * Quick release for a fix around aliasing in v1.3.
  - From 1.3.0
  * Add support for the Google Application Default Credentials.
  * Require python 2.6 as a minimum version.
  * Update several API samples.
  * Finish splitting out oauth2client repo and update tests.
  * Various doc cleanup and bugfixes.
  * Two important notes:
  * We've added `googleapiclient` as the primary suggested import
    name, and kept `apiclient` as an alias, in order to have a more
    appropriate import name. At some point, we will remove `apiclient`
    as an alias.
  * Due to an issue around in-place upgrades for Python packages,
    it's not possible to do an upgrade from version 1.2 to 1.3. Instead,
    setup.py attempts to detect this and prevents it. Simply remove
    the previous version and reinstall to fix this.
* Tue Mar  4 2014 rschweikert@suse.com
- Fix dependency issue, do not include uritemplate, this is an
  independent upstream code stream
- Add patch no_embed_uritempl_dep.patch
* Thu Feb 13 2014 rschweikert@suse.com
- include in SLE 12 (FATE #316168)
* Wed Oct 30 2013 rschweikert@suse.com
- update to version 1.2
  * The use of the gflags library is now deprecated, and is no longer a
    dependency. If you are still using the oauth2client.tools.run() function
    then include gflags as a dependency of your application or switch to
    oauth2client.tools.run_flow.
  * Samples have been updated to use the new apiclient.sample_tools, and no
    longer use gflags.
  * Added support for the experimental Object Change Notification, as found in
    the Cloud Storage API.
  * The oauth2client App Engine decorators are now threadsafe.
  * Use the following redirects feature of httplib2 where it returns the
    ultimate URL after a series of redirects to avoid multiple hops for every
    resumable media upload request.
  * Updated AdSense Management API samples to V1.3
  * Add option to automatically retry requests.
  * Ability to list registered keys in multistore_file.
  * User-agent must contain (gzip).
  * The 'method' parameter for httplib2 is not positional. This would cause
    spurious warnings in the logging.
  * Making OAuth2Decorator more extensible. Fixes Issue 256.
  * Update AdExchange Buyer API examples to version v1.2.
* Tue Aug  6 2013 rschweikert@suse.com
- Initial build
